package com.vendor.platform.ui.internal;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.platform.api.IDeviceChangedListener;
import com.vendor.platform.api.chips.Chip;
import com.vendor.platform.api.chips.Tool;
import com.vendor.platform.core.internal.DeviceManager;
import com.vendor.platform.ui.internal.BundleUtils;
import com.vendor.platform.ui.internal.PerspectiveUtil;
import com.vendor.platform.ui.internal.ToolEntryAction;
import java.util.ArrayList;
import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IExtension;
import org.eclipse.core.runtime.IExtensionPoint;
import org.eclipse.core.runtime.IExtensionRegistry;
import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.IContributionItem;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.ToolBarContributionItem;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.internal.WorkbenchWindow;
import org.eclipse.ui.internal.registry.PerspectiveDescriptor;
import org.eclipse.ui.internal.registry.PerspectiveRegistry;

public class ToolEntryBarManager implements IDeviceChangedListener {
  public static final com.vendor.platform.ui.internal.ToolEntryBarManager INSTANCE = new com.vendor.platform.ui.internal.ToolEntryBarManager();
  
  private static final String CHIP_BURN_TOOL = "Flasher";
  
  public void init() {
    DeviceManager.getInstance().addDeviceChangedListener(this);
  }
  
  public void deviceChanged(Chip chip) {
    IToolBarManager toolbar = null;
    WorkbenchWindow window = (WorkbenchWindow)PlatformUI.getWorkbench().getActiveWorkbenchWindow();
    IContributionItem[] items = window.getCoolBarManager2().getItems();
    for (IContributionItem item : items) {
      if (item instanceof ToolBarContributionItem) {
        ToolBarContributionItem toolBarContributionItem = (ToolBarContributionItem)item;
        if (toolBarContributionItem.getId().equals("tool_entry")) {
          toolbar = toolBarContributionItem.getToolBarManager();
          break;
        } 
      } 
    } 
    if (toolbar == null)
      return; 
    toolbar.removeAll();
    ArrayList<String> perspectivesIds = new ArrayList<>();
    IExtensionRegistry extReg = Platform.getExtensionRegistry();
    IExtensionPoint ep = extReg.getExtensionPoint("org.eclipse.ui.perspectives");
    IExtension[] extensions = ep.getExtensions();
    for (IExtension extension : extensions) {
      IConfigurationElement[] configurationElements = extension.getConfigurationElements();
      for (IConfigurationElement element : configurationElements) {
        String perspectiveID = element.getAttribute("id");
        if (perspectiveID.contains("com.vendor"))
          perspectivesIds.add(perspectiveID); 
      } 
    } 
    PerspectiveRegistry persReg = (PerspectiveRegistry)PlatformUI.getWorkbench().getPerspectiveRegistry();
    PerspectiveDescriptor perspective = (PerspectiveDescriptor)persReg.findPerspectiveWithId("com.vendor.platform.ui.Perspective");
    ToolEntryAction action = new ToolEntryAction(perspective.getLabel(), perspective);
    if (!action.init())
      return; 
    ArrayList<Tool> tools = chip.getToolList();
    boolean isChipPart4 = false;
    for (Tool item : tools) {
      if ("Flasher".equalsIgnoreCase(item.getId()))
        isChipPart4 = true; 
    } 
    ActionContributionItem tbci = new ActionContributionItem((IAction)action);
    tbci.setMode(ActionContributionItem.MODE_FORCE_TEXT);
    tbci.setVisible(!isChipPart4);
    toolbar.add((IContributionItem)tbci);
    for (String perspectiveID : perspectivesIds) {
      perspective = (PerspectiveDescriptor)persReg.findPerspectiveWithId(perspectiveID);
      if (perspective == null)
        continue; 
      if (!BundleUtils.isExistentTool(perspectiveID)) {
        if (window.getActivePage().getPerspective() == perspective) {
          try {
            PerspectiveUtil.openPerspective("com.vendor.platform.ui.Perspective");
          } catch (Exception e) {
            e.printStackTrace();
          } 
          continue;
        } 
        PerspectiveUtil.closePerpective(perspective.getId());
        continue;
      } 
      String toolName = "";
      String[] toolsMap = BundleUtils.TOOLS_AND_CLASSES_ARR[0];
      String[] classMap = BundleUtils.TOOLS_AND_CLASSES_ARR[1];
      for (int i = 0; i < classMap.length; i++) {
        String className = classMap[i];
        if (perspectiveID.equals(className))
          toolName = toolsMap[i]; 
      } 
      toolName = getToolName(isChipPart4, toolName);
      action = new ToolEntryAction(toolName, perspective);
      if (!action.init())
        continue; 
      tbci = new ActionContributionItem((IAction)action);
      tbci.setMode(ActionContributionItem.MODE_FORCE_TEXT);
      tbci.setVisible(!isChipPart4);
      toolbar.add((IContributionItem)tbci);
    } 
    toolbar.update(true);
  }
  
  private String getToolName(boolean isChipPart4, String toolName) {
    String name = toolName;
    if (isChipPart4 && "BurnTool".equals(toolName))
      name = "Flasher"; 
    return name;
  }
}
